@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -30,6 +30,8 @@
 #include <valgrind/valgrind.h>
 #endif
 
+#include "starpu_cusolver.h"
+
 static unsigned long size = 0;
 static unsigned nblocks = 0;
 static unsigned check = 0;
@@ -105,6 +107,7 @@ static void parse_args(int argc, char **argv)
 		}
 		else if (strcmp(argv[i], "-directory") == 0)
 		{
+			free(directory);
 			directory = strdup(argv[++i]);
 		}
 		else if (strcmp(argv[i], "-h") == 0 || strcmp(argv[i], "--help") == 0)
@@ -154,7 +157,7 @@ void copy_blocks_into_matrix(void)
 				A_blocks[bi+nblocks*bj][i + j * blocksize];
 		}
 
-		starpu_free(A_blocks[bi+nblocks*bj]);
+		starpu_free_noflag(A_blocks[bi+nblocks*bj], (size_t)blocksize*blocksize*sizeof(TYPE));
 	}
 }
 
@@ -316,7 +319,7 @@ static void check_result(void)
 
 	FPRINTF(stderr, "||%sA-LU|| / (||A||*N) : %e\n", pivot?"P":"", residual/(matnorm*size));
 
-	if (residual/(matnorm*size) > 1e-5)
+	if (residual/(matnorm*size) > PIVOT_THRESHHOLD)
 		exit(-1);
 
 	free(L);
@@ -361,6 +364,7 @@ int main(int argc, char **argv)
 #endif
 
 	starpu_cublas_init();
+	starpu_cusolver_init();
 
 	init_matrix();
 
@@ -377,7 +381,7 @@ int main(int argc, char **argv)
 	/* Factorize the matrix (in place) */
 	if (pivot)
 	{
- 		ipiv = malloc(size*sizeof(unsigned));
+		ipiv = malloc(size*sizeof(unsigned));
 		if (no_stride)
 		{
 			/* in case the LU decomposition uses non-strided blocks, we _copy_ the matrix into smaller blocks */
@@ -466,6 +470,7 @@ int main(int argc, char **argv)
 	starpu_free_flags(A, (size_t)size*size*sizeof(TYPE), STARPU_MALLOC_PINNED|STARPU_MALLOC_SIMULATION_FOLDED);
 #endif
 
+	starpu_cusolver_shutdown();
 	starpu_cublas_shutdown();
 
 	starpu_shutdown();
