@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -31,9 +31,7 @@
 #include <starpu.h>
 
 #define FPRINTF(ofile, fmt, ...) do { if (!getenv("STARPU_SSILENT")) {fprintf(ofile, fmt, ## __VA_ARGS__); }} while(0)
-#define TAG(i, iter)	((starpu_tag_t)  (((uint64_t)iter)<<32 | (i)) )
-
-struct starpu_codelet cl;
+#define TAG(i, iter)	((starpu_tag_t)  (((uint64_t)iter)<<32 | (i)))
 
 #define Ni	64
 #define Nk	256
@@ -87,7 +85,7 @@ static int create_task_grid(unsigned iter)
 		/* create a new task */
 		struct starpu_task *task = starpu_task_create();
 
-		task->cl = &cl;
+		task->cl = &starpu_codelet_nop;
 		task->cl_arg = NULL;
 
 		task->use_tag = 1;
@@ -126,14 +124,6 @@ int main(int argc, char **argv)
 
 	parse_args(argc, argv);
 
-	starpu_codelet_init(&cl);
-	cl.cpu_funcs[0] = cpu_codelet;
-	cl.cpu_funcs_name[0] = "cpu_codelet";
-	cl.cuda_funcs[0] = cpu_codelet;
-	cl.opencl_funcs[0] = cpu_codelet;
-	cl.nbuffers = 0;
-	cl.name = "dummy";
-
 	FPRINTF(stderr, "ITER : %u\n", nk);
 
 	for (i = 0; i < nk; i++)
