@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -535,7 +535,7 @@ struct starpu_conf
 	uint64_t trace_buffer_size;
 
 	/**
-	   Set the mininum priority used by priorities-aware
+	   Set the minimum priority used by priorities-aware
 	   schedulers.
 	   This also can be specified with the environment variable \ref
 	   STARPU_MIN_PRIO
@@ -543,7 +543,7 @@ struct starpu_conf
 	int global_sched_ctx_min_priority;
 
 	/**
-	   Set the maxinum priority used by priorities-aware
+	   Set the maximum priority used by priorities-aware
 	   schedulers.
 	   This also can be specified with the environment variable \ref
 	   STARPU_MAX_PRIO
@@ -559,7 +559,7 @@ struct starpu_conf
 	   Specify if StarPU should catch \c SIGINT, \c SIGSEGV and \c SIGTRAP
 	   signals to make sure final actions (e.g dumping FxT trace
 	   files) are done even though the application has crashed. By
-	   default (value = \c 1), signals are catched. It should be
+	   default (value = \c 1), signals are caught. It should be
 	   disabled on systems which already catch these signals for
 	   their own needs (e.g JVM)
 	   This can also be specified with the environment variable
@@ -717,6 +717,48 @@ unsigned starpu_get_next_bindid(unsigned flags, unsigned *preferred, unsigned np
 */
 int starpu_bind_thread_on(int cpuid, unsigned flags, const char *name);
 
+/**
+   Bind the calling thread on the cores corresponding to the \p workerid .
+
+   \p workerid can be a basic worker or a combined worker.
+
+   This can be used e.g. before initializing a library which records at
+   initialization time the thread binding to be used when running kernels.
+
+   See \ref KernelThreadsStartedByStarPU and \ref cpuWorkers for more details.
+*/
+void starpu_bind_thread_on_worker(unsigned workerid);
+
+/**
+   Bind the calling thread back to the core reserved for the main thread.
+
+   This can be used e.g. after initializing a library which records at
+   initialization time the thread binding to be used when running kernels.
+
+   See \ref KernelThreadsStartedByStarPU and \ref cpuWorkers for more details.
+*/
+void starpu_bind_thread_on_main(void);
+
+/**
+   Bind the calling thread on the given \p cpuid
+
+   This can be used e.g. after initializing a library which records at
+   initialization time the thread binding to be used when running kernels.
+
+   See \ref KernelThreadsStartedByStarPU and \ref cpuWorkers for more details.
+*/
+void starpu_bind_thread_on_cpu(int cpuid);
+
+/**
+   Return the OS number of a given \p cpuid
+
+   StarPU uses logical numbering (as define by hwloc) all along, but in case
+   interaction is needed with another binding tool that uses numbering as
+   defined by the OS, we need to convert from hwloc logical numbering to hwloc
+   physical numbering.
+*/
+int starpu_cpu_os_index(int cpuid);
+
 /**
    Print a description of the topology on \p f.
    See \ref ConfigurationAndInitialization for more details.
