@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -48,7 +48,9 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 		if(nhierarchy_levels > 1)
 			ready_flops = sc_hypervisor_get_nready_flops_of_all_sons_of_sched_ctx(sc_w->sched_ctx);
 
+#ifdef STARPU_SC_HYPERVISOR_DEBUG
 		int nready_tasks = starpu_sched_ctx_get_nready_tasks(sc_w->sched_ctx);
+#endif
 
 		if(sc_w->to_be_sized)
 		{
@@ -126,7 +128,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 
 	if(nsched_ctxs == 1)
 	{
-		int w;
 		for(w = 0; w < nw; w++)
 			res[0][w] = total_nw[w];
 		double optimal_v = 0.0;
@@ -153,7 +154,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 		{
 			tmp_sched_ctxs[tmp_nsched_ctxs] = sched_ctxs[i];
 			tmp_flops[tmp_nsched_ctxs] = flops[i];
-			int w;
 			for(w = 0; w < ntypes_of_workers; w++)
 				tmp_v[tmp_nsched_ctxs][w] = v[i][w];
 			tmp_nsched_ctxs++;
@@ -171,7 +171,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 		{
 			if(sched_ctxs[i] == tmp_sched_ctxs[j])
 			{
-				int w;
 				for(w = 0; w < ntypes_of_workers; w++)
 					res[i][w] = tmp_res[j][w];
 				found = 1;
@@ -180,7 +179,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 		}
 		if(!found)
 		{
-			int w;
 			for(w = 0; w < ntypes_of_workers; w++)
 				res[i][w] = 0.0;
 		}
@@ -234,7 +232,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 
 			if(ret != 0)
 			{
-				int j;
 				for(i = 0; i < nsched_ctxs; i++)
 				{
 					for(j = 0; j < nselected; j++)
@@ -257,7 +254,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 	if(ret == 0.0)
 	{
 		double rand_res[nw];
-		int w;
 		for(w = 0; w < nw; w++)
 			rand_res[w] = total_nw[w]/nsched_ctxs;
 		int s;
@@ -280,7 +276,6 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 #else
 		optimal_v = res[i][0] * v[i][0];
 #endif //STARPU_USE_CUDA
-		int w;
 		unsigned no_workers = 1;
 		for(w = 0; w < nw; w++)
 		{
@@ -294,11 +289,12 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 		sc_w = sc_hypervisor_get_wrapper(sched_ctxs[i]);
 
 /* if the hypervisor gave 0 workers to a context but the context still
-   has some last flops or a ready task that does not even have any flops
-   we give a worker (in shared mode) to the context in order to leave him
-   finish its work = we give -1.0 value instead of 0.0 and further on in
-   the distribution function we take this into account and revert the variable
-   to its 0.0 value */
+ * has some last flops or a ready task that does not even have any flops
+ * we give a worker (in shared mode) to the context in order to leave him
+ * finish its work = we give -1.0 value instead of 0.0 and further on in
+ * the distribution function we take this into account and revert the variable
+ * to its 0.0 value
+*/
 //		if(no_workers && (flops[i] != 0.0 || sc_w->nready_tasks > 0))
 		if(no_workers)
 		{
@@ -319,10 +315,10 @@ double sc_hypervisor_lp_get_nworkers_per_ctx(int nsched_ctxs, int ntypes_of_work
 double sc_hypervisor_lp_get_tmax(int nworkers, int *workers)
 {
 	struct types_of_workers *tw = sc_hypervisor_get_types_of_workers(workers, nworkers);
-        int nw = tw->nw;
+	int nw = tw->nw;
 
-        int total_nw[nw];
-        sc_hypervisor_group_workers_by_type(tw, total_nw);
+	int total_nw[nw];
+	sc_hypervisor_group_workers_by_type(tw, total_nw);
 
 	int nsched_ctxs = sc_hypervisor_get_nsched_ctxs();
 
@@ -490,7 +486,7 @@ void _lp_find_workers_to_accept(int nw, int ns, unsigned sched_ctx, int sched_ct
 		int nw_ctx2 = sc_hypervisor_get_nworkers_ctx(sched_ctx, arch);
 		int nw_needed = res_rounded[sched_ctx_idx][w] - nw_ctx2;
 
-		if( nw_needed > 0 && tmp_nw_move[w] > 0)
+		if(nw_needed > 0 && tmp_nw_move[w] > 0)
 		{
 			*nw_move += nw_needed >= tmp_nw_move[w] ? tmp_nw_move[w] : nw_needed;
 			int i = 0;
@@ -669,7 +665,7 @@ void sc_hypervisor_lp_distribute_resources_in_ctxs(unsigned* sched_ctxs, int ns,
 	for(s = 0; s < ns; s++)
 	{
 		int workers_add[STARPU_NMAXWORKERS];
-                int nw_add = 0;
+		int nw_add = 0;
 		double target_res = 0.0;
 		for(w = 0; w < nw; w++)
 		{
@@ -756,7 +752,7 @@ void sc_hypervisor_lp_distribute_floating_no_resources_in_ctxs(unsigned* sched_c
 	for(s = 0; s < ns; s++)
 	{
 		int workers_add[STARPU_NMAXWORKERS];
-                int nw_add = 0;
+		int nw_add = 0;
 		double target_res = 0.0;
 		for(w = 0; w < nw; w++)
 		{
