@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010       Mehdi Juhoor
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2010  Mehdi Juhoor
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -19,43 +19,10 @@
 #include <common/config.h>
 #include <datawizard/filters.h>
 
-void starpu_vector_filter_block(void *father_interface, void *child_interface, STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, unsigned id, unsigned nchunks)
+static void _starpu_vector_filter_block(void *father_interface, void *child_interface, STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, unsigned id, unsigned nchunks, uintptr_t shadow_size)
 {
-        struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
-        struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
-
-	uint32_t nx = vector_father->nx;
-	size_t elemsize = vector_father->elemsize;
-
-	STARPU_ASSERT_MSG(nchunks <= nx, "cannot split %u elements in %u parts", nx, nchunks);
-
-	uint32_t child_nx;
-	size_t offset;
-	starpu_filter_nparts_compute_chunk_size_and_offset(nx, nchunks, elemsize, id, 1, &child_nx, &offset);
-
-	STARPU_ASSERT_MSG(vector_father->id == STARPU_VECTOR_INTERFACE_ID, "%s can only be applied on a vector data", __func__);
-	vector_child->id = vector_father->id;
-	vector_child->nx = child_nx;
-	vector_child->elemsize = elemsize;
-	STARPU_ASSERT_MSG(vector_father->allocsize == vector_father->nx * vector_father->elemsize, "partitioning vector with non-trival allocsize not supported yet, patch welcome");
-	vector_child->allocsize = vector_child->nx * elemsize;
-
-	if (vector_father->dev_handle)
-	{
-		if (vector_father->ptr)
-			vector_child->ptr = vector_father->ptr + offset;
-		vector_child->dev_handle = vector_father->dev_handle;
-		vector_child->offset = vector_father->offset + offset;
-	}
-}
-
-
-void starpu_vector_filter_block_shadow(void *father_interface, void *child_interface, STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, unsigned id, unsigned nchunks)
-{
-        struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
-        struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
-
-        uintptr_t shadow_size = (uintptr_t) f->filter_arg_ptr;
+	struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
+	struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
 
 	/* actual number of elements */
 	uint32_t nx = vector_father->nx - 2 * shadow_size;
@@ -72,7 +39,6 @@ void starpu_vector_filter_block_shadow(void *father_interface, void *child_inter
 	vector_child->id = vector_father->id;
 	vector_child->nx = child_nx;
 	vector_child->elemsize = elemsize;
-	STARPU_ASSERT_MSG(vector_father->allocsize == vector_father->nx * vector_father->elemsize, "partitioning vector with non-trival allocsize not supported yet, patch welcome");
 	vector_child->allocsize = vector_child->nx * elemsize;
 
 	if (vector_father->dev_handle)
@@ -84,10 +50,23 @@ void starpu_vector_filter_block_shadow(void *father_interface, void *child_inter
 	}
 }
 
+void starpu_vector_filter_block(void *father_interface, void *child_interface, STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, unsigned id, unsigned nchunks)
+{
+	_starpu_vector_filter_block(father_interface, child_interface, f, id, nchunks, 0);
+}
+
+
+void starpu_vector_filter_block_shadow(void *father_interface, void *child_interface, STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, unsigned id, unsigned nchunks)
+{
+	uintptr_t shadow_size = (uintptr_t) f->filter_arg_ptr;
+
+	_starpu_vector_filter_block(father_interface, child_interface, f, id, nchunks, shadow_size);
+}
+
 
 void starpu_vector_filter_divide_in_2(void *father_interface, void *child_interface, struct starpu_data_filter *f, unsigned id, STARPU_ATTRIBUTE_UNUSED unsigned nchunks)
 {
-        /* there cannot be more than 2 chunks */
+	/* there cannot be more than 2 chunks */
 	STARPU_ASSERT_MSG(id < 2, "Only %u parts", id);
 
 	struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
@@ -102,7 +81,6 @@ void starpu_vector_filter_divide_in_2(void *father_interface, void *child_interf
 
 	STARPU_ASSERT_MSG(vector_father->id == STARPU_VECTOR_INTERFACE_ID, "%s can only be applied on a vector data", __func__);
 	vector_child->id = vector_father->id;
-	STARPU_ASSERT_MSG(vector_father->allocsize == vector_father->nx * vector_father->elemsize, "partitioning vector with non-trival allocsize not supported yet, patch welcome");
 
 	/* this is the first child */
 	if (id == 0)
@@ -138,10 +116,10 @@ void starpu_vector_filter_divide_in_2(void *father_interface, void *child_interf
 
 void starpu_vector_filter_list_long(void *father_interface, void *child_interface, struct starpu_data_filter *f, unsigned id, STARPU_ATTRIBUTE_UNUSED unsigned nchunks)
 {
-        struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
-        struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
+	struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
+	struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
 
-        long *length_tab = (long *) f->filter_arg_ptr;
+	long *length_tab = (long *) f->filter_arg_ptr;
 
 	size_t elemsize = vector_father->elemsize;
 
@@ -151,7 +129,6 @@ void starpu_vector_filter_list_long(void *father_interface, void *child_interfac
 	vector_child->id = vector_father->id;
 	vector_child->nx = chunk_size;
 	vector_child->elemsize = elemsize;
-	STARPU_ASSERT_MSG(vector_father->allocsize == vector_father->nx * vector_father->elemsize, "partitioning vector with non-trival allocsize not supported yet, patch welcomed");
 	vector_child->allocsize = vector_child->nx * elemsize;
 
 	if (vector_father->dev_handle)
@@ -171,10 +148,10 @@ void starpu_vector_filter_list_long(void *father_interface, void *child_interfac
 
 void starpu_vector_filter_list(void *father_interface, void *child_interface, struct starpu_data_filter *f, unsigned id, STARPU_ATTRIBUTE_UNUSED unsigned nchunks)
 {
-        struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
-        struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
+	struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
+	struct starpu_vector_interface *vector_child = (struct starpu_vector_interface *) child_interface;
 
-        uint32_t *length_tab = (uint32_t *) f->filter_arg_ptr;
+	uint32_t *length_tab = (uint32_t *) f->filter_arg_ptr;
 
 	size_t elemsize = vector_father->elemsize;
 
@@ -184,7 +161,6 @@ void starpu_vector_filter_list(void *father_interface, void *child_interface, st
 	vector_child->id = vector_father->id;
 	vector_child->nx = chunk_size;
 	vector_child->elemsize = elemsize;
-	STARPU_ASSERT_MSG(vector_father->allocsize == vector_father->nx * vector_father->elemsize, "partitioning vector with non-trival allocsize not supported yet, patch welcomed");
 	vector_child->allocsize = vector_child->nx * elemsize;
 
 	if (vector_father->dev_handle)
@@ -201,3 +177,39 @@ void starpu_vector_filter_list(void *father_interface, void *child_interface, st
 		vector_child->dev_handle = vector_father->dev_handle;
 	}
 }
+
+void starpu_vector_filter_pick_variable(void *father_interface, void *child_interface, STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, unsigned id, unsigned nchunks)
+{
+	struct starpu_vector_interface *vector_father = (struct starpu_vector_interface *) father_interface;
+	/* each chunk becomes a variable */
+	struct starpu_variable_interface *variable_child = (struct starpu_variable_interface *) child_interface;
+
+	/* actual number of elements */
+	uint32_t nx = vector_father->nx;
+	size_t elemsize = vector_father->elemsize;
+
+	size_t chunk_pos = (size_t)f->filter_arg_ptr;
+
+	STARPU_ASSERT_MSG(nchunks <= nx, "cannot get %u variables", nchunks);
+	STARPU_ASSERT_MSG((chunk_pos + id) < nx, "the chosen variable should be in the vector");
+
+	size_t offset = (chunk_pos + id) * elemsize;
+
+	STARPU_ASSERT_MSG(vector_father->id == STARPU_VECTOR_INTERFACE_ID, "%s can only be applied on a vector data", __func__);
+
+	variable_child->id = STARPU_VARIABLE_INTERFACE_ID;
+	variable_child->elemsize = elemsize;
+
+	if (vector_father->dev_handle)
+	{
+		if (vector_father->ptr)
+			variable_child->ptr = vector_father->ptr + offset;
+		variable_child->dev_handle = vector_father->dev_handle;
+		variable_child->offset = vector_father->offset + offset;
+	}
+}
+
+struct starpu_data_interface_ops *starpu_vector_filter_pick_variable_child_ops(STARPU_ATTRIBUTE_UNUSED struct starpu_data_filter *f, STARPU_ATTRIBUTE_UNUSED unsigned child)
+{
+	return &starpu_interface_variable_ops;
+}
