@@ -1,11 +1,11 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2010	    Mehdi Juhoor
- * Copyright (C) 2011	    Télécom-SudParis
- * Copyright (C) 2013	    Thibaut Lambert
- * Copyright (C) 2021	    Federal University of Rio Grande do Sul (UFRGS)
- * Copyright (C) 2022	    Camille Coti
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2022,2023  École de Technologie Supérieure (ETS, Montréal)
+ * Copyright (C) 2013-2013  Thibaut Lambert
+ * Copyright (C) 2011-2011  Télécom Sud Paris
+ * Copyright (C) 2010-2010  Mehdi Juhoor
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -135,7 +135,7 @@ void _starpu_opencl_init(void)
 		cl_device_type device_type = CL_DEVICE_TYPE_GPU|CL_DEVICE_TYPE_ACCELERATOR;
 
 		_STARPU_DEBUG("Initialising OpenCL\n");
-        
+
 		// Get Platforms
 		if (starpu_getenv_number("STARPU_OPENCL_ON_CPUS") > 0)
 		     device_type |= CL_DEVICE_TYPE_CPU;
@@ -565,7 +565,7 @@ static void _starpu_opencl_limit_gpu_mem_if_needed(unsigned devid)
 }
 
 /* This is run from the driver thread to initialize the driver OpenCL context */
-int _starpu_opencl_driver_init(struct _starpu_worker *worker)
+static int _starpu_opencl_driver_init(struct _starpu_worker *worker)
 {
 	int devid = worker->devid;
 
@@ -637,7 +637,7 @@ int _starpu_opencl_driver_init(struct _starpu_worker *worker)
 	return 0;
 }
 
-int _starpu_opencl_driver_deinit(struct _starpu_worker *worker)
+static int _starpu_opencl_driver_deinit(struct _starpu_worker *worker)
 {
 	_STARPU_TRACE_WORKER_DEINIT_START;
 
@@ -706,7 +706,7 @@ cl_int starpu_opencl_allocate_memory(int devid STARPU_ATTRIBUTE_UNUSED, cl_mem *
 }
 #endif
 
-uintptr_t _starpu_opencl_malloc_on_node(unsigned dst_node, size_t size, int flags)
+static uintptr_t _starpu_opencl_malloc_on_node(unsigned dst_node, size_t size, int flags)
 {
 	(void)flags;
 	uintptr_t addr = 0;
@@ -739,7 +739,7 @@ uintptr_t _starpu_opencl_malloc_on_node(unsigned dst_node, size_t size, int flag
 	return addr;
 }
 
-void _starpu_opencl_free_on_node(unsigned dst_node, uintptr_t addr, size_t size, int flags)
+static void _starpu_opencl_free_on_node(unsigned dst_node, uintptr_t addr, size_t size, int flags)
 {
 	(void)dst_node;
 	(void)addr;
@@ -919,7 +919,7 @@ static inline cl_event *_starpu_opencl_event(union _starpu_async_channel_event *
 	return event;
 }
 
-int _starpu_opencl_copy_data_from_opencl_to_opencl(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
+static int _starpu_opencl_copy_data_from_opencl_to_opencl(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -931,7 +931,7 @@ int _starpu_opencl_copy_data_from_opencl_to_opencl(uintptr_t src, size_t src_off
 					     _starpu_opencl_event(&async_channel->event));
 }
 
-int _starpu_opencl_copy_data_from_opencl_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
+static int _starpu_opencl_copy_data_from_opencl_to_cpu(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -943,7 +943,7 @@ int _starpu_opencl_copy_data_from_opencl_to_cpu(uintptr_t src, size_t src_offset
 					     _starpu_opencl_event(&async_channel->event));
 }
 
-int _starpu_opencl_copy_data_from_cpu_to_opencl(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
+static int _starpu_opencl_copy_data_from_cpu_to_opencl(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size, struct _starpu_async_channel *async_channel)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -956,7 +956,7 @@ int _starpu_opencl_copy_data_from_cpu_to_opencl(uintptr_t src, size_t src_offset
 }
 
 #if 0
-cl_int _starpu_opencl_copy_rect_opencl_to_ram(cl_mem buffer, unsigned src_node STARPU_ATTRIBUTE_UNUSED, void *ptr, unsigned dst_node STARPU_ATTRIBUTE_UNUSED, const size_t buffer_origin[3], const size_t host_origin[3],
+static cl_int _starpu_opencl_copy_rect_opencl_to_ram(cl_mem buffer, unsigned src_node STARPU_ATTRIBUTE_UNUSED, void *ptr, unsigned dst_node STARPU_ATTRIBUTE_UNUSED, const size_t buffer_origin[3], const size_t host_origin[3],
 					      const size_t region[3], size_t buffer_row_pitch, size_t buffer_slice_pitch,
 					      size_t host_row_pitch, size_t host_slice_pitch, cl_event *event)
 {
@@ -978,7 +978,7 @@ cl_int _starpu_opencl_copy_rect_opencl_to_ram(cl_mem buffer, unsigned src_node S
 	return CL_SUCCESS;
 }
 
-cl_int _starpu_opencl_copy_rect_ram_to_opencl(void *ptr, unsigned src_node STARPU_ATTRIBUTE_UNUSED, cl_mem buffer, unsigned dst_node STARPU_ATTRIBUTE_UNUSED, const size_t buffer_origin[3], const size_t host_origin[3],
+static cl_int _starpu_opencl_copy_rect_ram_to_opencl(void *ptr, unsigned src_node STARPU_ATTRIBUTE_UNUSED, cl_mem buffer, unsigned dst_node STARPU_ATTRIBUTE_UNUSED, const size_t buffer_origin[3], const size_t host_origin[3],
 					      const size_t region[3], size_t buffer_row_pitch, size_t buffer_slice_pitch,
 					      size_t host_row_pitch, size_t host_slice_pitch, cl_event *event)
 {
@@ -1001,7 +1001,7 @@ cl_int _starpu_opencl_copy_rect_ram_to_opencl(void *ptr, unsigned src_node STARP
 }
 #endif
 
-unsigned _starpu_opencl_test_request_completion(struct _starpu_async_channel *async_channel)
+static unsigned _starpu_opencl_test_request_completion(struct _starpu_async_channel *async_channel)
 {
 	cl_int event_status;
 	cl_event opencl_event = *_starpu_opencl_event(&async_channel->event);
@@ -1019,7 +1019,8 @@ unsigned _starpu_opencl_test_request_completion(struct _starpu_async_channel *as
 	return (event_status == CL_COMPLETE);
 }
 
-void _starpu_opencl_wait_request_completion(struct _starpu_async_channel *async_channel)
+/* Only used at starpu_shutdown */
+static void _starpu_opencl_wait_request_completion(struct _starpu_async_channel *async_channel)
 {
 	cl_int err;
 	if (*_starpu_opencl_event(&async_channel->event) == NULL)
@@ -1032,7 +1033,7 @@ void _starpu_opencl_wait_request_completion(struct _starpu_async_channel *async_
 		STARPU_OPENCL_REPORT_ERROR(err);
 }
 
-int _starpu_opencl_copy_interface_from_opencl_to_opencl(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_opencl_copy_interface_from_opencl_to_opencl(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1065,7 +1066,7 @@ int _starpu_opencl_copy_interface_from_opencl_to_opencl(starpu_data_handle_t han
 	return ret;
 }
 
-int _starpu_opencl_copy_interface_from_opencl_to_cpu(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_opencl_copy_interface_from_opencl_to_cpu(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1098,7 +1099,7 @@ int _starpu_opencl_copy_interface_from_opencl_to_cpu(starpu_data_handle_t handle
 	return ret;
 }
 
-int _starpu_opencl_copy_interface_from_cpu_to_opencl(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
+static int _starpu_opencl_copy_interface_from_cpu_to_opencl(starpu_data_handle_t handle, void *src_interface, unsigned src_node, void *dst_interface, unsigned dst_node, struct _starpu_data_request *req)
 {
 	int src_kind = starpu_node_get_kind(src_node);
 	int dst_kind = starpu_node_get_kind(dst_node);
@@ -1131,7 +1132,7 @@ int _starpu_opencl_copy_interface_from_cpu_to_opencl(starpu_data_handle_t handle
 	return ret;
 }
 
-uintptr_t
+static uintptr_t
 _starpu_opencl_map_ram(uintptr_t src, size_t src_offset, unsigned src_node STARPU_ATTRIBUTE_UNUSED,
 		      unsigned dst_node STARPU_ATTRIBUTE_UNUSED, size_t size, int *ret)
 {
@@ -1153,7 +1154,7 @@ _starpu_opencl_map_ram(uintptr_t src, size_t src_offset, unsigned src_node STARP
 	return (uintptr_t)memory;
 }
 
-int
+static int
 _starpu_opencl_unmap_ram(uintptr_t src STARPU_ATTRIBUTE_UNUSED, size_t src_offset STARPU_ATTRIBUTE_UNUSED, unsigned src_node STARPU_ATTRIBUTE_UNUSED,
 			uintptr_t dst, unsigned dst_node STARPU_ATTRIBUTE_UNUSED, size_t size STARPU_ATTRIBUTE_UNUSED)
 {
@@ -1168,7 +1169,7 @@ _starpu_opencl_unmap_ram(uintptr_t src STARPU_ATTRIBUTE_UNUSED, size_t src_offse
 	return 0;
 }
 
-int
+static int
 _starpu_opencl_update_opencl_map(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size)
 {
 	(void) size;
@@ -1197,7 +1198,7 @@ _starpu_opencl_update_opencl_map(uintptr_t src, size_t src_offset, unsigned src_
 	return 0;
 }
 
-int
+static int
 _starpu_opencl_update_cpu_map(uintptr_t src, size_t src_offset, unsigned src_node, uintptr_t dst, size_t dst_offset, unsigned dst_node, size_t size)
 {
 	(void) size;
@@ -1230,7 +1231,7 @@ _starpu_opencl_update_cpu_map(uintptr_t src, size_t src_offset, unsigned src_nod
 
 #endif /* STARPU_USE_OPENCL */
 
-int _starpu_opencl_is_direct_access_supported(unsigned node, unsigned handling_node)
+static int _starpu_opencl_is_direct_access_supported(unsigned node, unsigned handling_node)
 {
 	(void)node;
 	(void)handling_node;
@@ -1428,7 +1429,7 @@ static void _starpu_opencl_stop_job(struct _starpu_job *j, struct _starpu_worker
 
 }
 
-int _starpu_opencl_driver_run_once(struct _starpu_worker *worker)
+static int _starpu_opencl_driver_run_once(struct _starpu_worker *worker)
 {
 	int workerid = worker->workerid;
 	unsigned memnode = worker->memory_node;
@@ -1637,7 +1638,7 @@ void *_starpu_opencl_worker(void *_arg)
 }
 
 #ifdef STARPU_USE_OPENCL
-int _starpu_run_opencl(struct _starpu_worker *workerarg)
+static int _starpu_run_opencl(struct _starpu_worker *workerarg)
 {
 	_STARPU_DEBUG("Running OpenCL %u from the application\n", workerarg->devid);
 
@@ -1647,14 +1648,14 @@ int _starpu_run_opencl(struct _starpu_worker *workerarg)
 	return 0;
 }
 
-int _starpu_opencl_driver_set_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
+static int _starpu_opencl_driver_set_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
 {
 	starpu_opencl_get_device(worker->devid, &driver->id.opencl_id);
 
 	return 0;
 }
 
-int _starpu_opencl_driver_is_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
+static int _starpu_opencl_driver_is_devid(struct starpu_driver *driver, struct _starpu_worker *worker)
 {
 	cl_device_id device;
 	starpu_opencl_get_device(worker->devid, &device);
