@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -23,16 +23,18 @@ void cpu_show_bcsr(void *descr[], void *arg)
 {
 	(void)arg;
 	struct starpu_bcsr_interface *iface = descr[0];
-	uint32_t nnz = iface->nnz;
-	uint32_t nrow = iface->nrow;
-	int *nzval = (int *)iface->nzval;
-	uint32_t *colind = iface->colind;
-	uint32_t *rowptr = iface->rowptr;
+	uint32_t nnz = STARPU_BCSR_GET_NNZ(iface);
+	uint32_t nrow = STARPU_BCSR_GET_NROW(iface);
+	int *nzval = (int *)STARPU_BCSR_GET_NZVAL(iface);
+	uint32_t *colind = STARPU_BCSR_GET_COLIND(iface);
+	uint32_t *rowptr = STARPU_BCSR_GET_ROWPTR(iface);
+	STARPU_ASSERT(colind == STARPU_BCSR_GET_RAM_COLIND(iface));
+	STARPU_ASSERT(rowptr == STARPU_BCSR_GET_RAM_ROWPTR(iface));
 
-	uint32_t firstentry = iface->firstentry;
-	uint32_t r = iface->r;
-	uint32_t c = iface->c;
-	uint32_t elemsize = iface->elemsize;
+	uint32_t firstentry = STARPU_BCSR_GET_FIRSTENTRY(iface);
+	uint32_t r = STARPU_BCSR_GET_R(iface);
+	uint32_t c = STARPU_BCSR_GET_C(iface);
+	uint32_t elemsize = STARPU_BCSR_GET_ELEMSIZE(iface);
 
 	uint32_t i, j, y, x;
 	static starpu_pthread_mutex_t mutex = STARPU_PTHREAD_MUTEX_INITIALIZER;
@@ -52,7 +54,7 @@ void cpu_show_bcsr(void *descr[], void *arg)
 		{
 			int *block = nzval + j * r*c;
 
-			printf( " column %u\n", colind[j]);
+			printf(" column %u\n", colind[j]);
 
 			for (y = 0; y < r; y++)
 			{
@@ -112,18 +114,21 @@ static uint32_t rowptr[NROWS+1] = { 0, 1, NNZ_BLOCKS, NNZ_BLOCKS };
 
 int main(int argc, char **argv)
 {
+	int ret;
 	struct starpu_conf conf;
 	starpu_conf_init(&conf);
 
 	conf.precedence_over_environment_variables = 1;
-	conf.ncuda = 0;
-	conf.nopencl = 0;
-	conf.nmic = 0;
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
 
 	if (starpu_initialize(&conf, &argc, &argv) == -ENODEV)
 		return STARPU_TEST_SKIPPED;
 
-	if (starpu_cpu_worker_get_count() == 0 || starpu_memory_nodes_get_count() > 1) {
+	if (starpu_cpu_worker_get_count() == 0 || starpu_memory_nodes_get_count() > 1)
+	{
 		starpu_shutdown();
 		return STARPU_TEST_SKIPPED;
 	}
@@ -140,7 +145,13 @@ int main(int argc, char **argv)
 				  C,
 				  sizeof(nzval[0]));
 
-	starpu_task_insert(&show_cl, STARPU_R, bcsr_handle, 0);
+	ret = starpu_task_insert(&show_cl, STARPU_R, bcsr_handle, 0);
+	if (ret == -ENODEV)
+	{
+		starpu_data_unregister(bcsr_handle);
+		starpu_shutdown();
+		return STARPU_TEST_SKIPPED;
+	}
 
 	struct starpu_data_filter filter =
 	{
@@ -149,9 +160,12 @@ int main(int argc, char **argv)
 	};
 	starpu_data_partition(bcsr_handle, &filter);
 
-	starpu_task_insert(&show_cl, STARPU_R, starpu_data_get_sub_data(bcsr_handle, 1, 0), 0);
-	starpu_task_insert(&show_cl, STARPU_R, starpu_data_get_sub_data(bcsr_handle, 1, 1), 0);
-	starpu_task_insert(&show_cl, STARPU_R, starpu_data_get_sub_data(bcsr_handle, 1, 2), 0);
+	ret = starpu_task_insert(&show_cl, STARPU_R, starpu_data_get_sub_data(bcsr_handle, 1, 0), 0);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+	ret = starpu_task_insert(&show_cl, STARPU_R, starpu_data_get_sub_data(bcsr_handle, 1, 1), 0);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
+	ret = starpu_task_insert(&show_cl, STARPU_R, starpu_data_get_sub_data(bcsr_handle, 1, 2), 0);
+	STARPU_CHECK_RETURN_VALUE(ret, "starpu_task_insert");
 
 	starpu_data_unpartition(bcsr_handle, STARPU_MAIN_RAM);
 
