@@ -1,8 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2010,2012                                Inria
- * Copyright (C) 2012-2013,2015,2017                      CNRS
- * Copyright (C) 2010-2011,2013-2014,2016                 Université de Bordeaux
+ * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -65,14 +63,12 @@ int main(int argc, char **argv)
 
 	for (i = 0; i < NUM_THREADS; ++i)
 	{
-		int ret = starpu_pthread_create(&threads[i], NULL, launch_starpu, NULL);
-		STARPU_ASSERT(ret == 0);
+		STARPU_PTHREAD_CREATE(&threads[i], NULL, launch_starpu, NULL);
 	}
 
 	for (i = 0; i < NUM_THREADS; ++i)
 	{
-		int ret = starpu_pthread_join(threads[i], NULL);
-		STARPU_ASSERT(ret == 0);
+		STARPU_PTHREAD_JOIN(threads[i], NULL);
 	}
 
 	end = starpu_timing_now();
@@ -85,14 +81,12 @@ int main(int argc, char **argv)
 
 	for (i = 0; i < NUM_THREADS; i++)
 	{
-		int ret = starpu_pthread_create(&threads[i], NULL, shutdown_starpu, NULL);
-		STARPU_ASSERT(ret == 0);
+		STARPU_PTHREAD_CREATE(&threads[i], NULL, shutdown_starpu, NULL);
 	}
 
 	for (i = 0; i < NUM_THREADS; i++)
 	{
-		int ret = starpu_pthread_join(threads[i], NULL);
-		STARPU_ASSERT(ret == 0);
+		STARPU_PTHREAD_JOIN(threads[i], NULL);
 	}
 
 	return EXIT_SUCCESS;
